<p align="center">
   <picture>
      <source media="(prefers-color-scheme: dark)" srcset="https://zapehr-public-files.s3.amazonaws.com/osytehr-logo-dark.svg">
      <source media="(prefers-color-scheme: dark)" srcset="https://zapehr-public-files.s3.amazonaws.com/osytehr-logo-dark.svg">
      <img alt="Oystehr Logo" src="https://zapehr-public-files.s3.amazonaws.com/oystehr-logo-white.svg" width=300px>
   </picture>
</p>

<p align="center">The complete health-tech developer platform.</p>

<p align="center">
    <a href="https://www.oystehr.com/"><b>Website</b></a> •
    <a href="https://docs.oystehr.com/"><b>Documentation</b></a>
</p>

<div align="center">

[![Version](https://badgen.net/npm/v/@zapehr/sdk)](https://npmjs.com/package/@zapehr/sdk)
[![Compatible Node Versions](https://badgen.net/npm/node/@zapehr/sdk)](https://npmjs.com/package/@zapehr/sdk)
[![Install Size](https://badgen.net/packagephobia/install/@zapehr/sdk)](https://packagephobia.com/result?p=%40zapehr%2Fsdk)
[![Minified Size](https://badgen.net/bundlephobia/min/@zapehr/sdk)](https://bundlephobia.com/package/@zapehr/sdk)
[![Downloads / Month](https://badgen.net/npm/dm/@zapehr/sdk)](https://npmjs.com/package/@zapehr/sdk)
[![License](https://badgen.net/npm/license/@zapehr/sdk)](https://npmjs.com/package/@zapehr/sdk)




</div>

<br/>
<br/>
<br/>

# THIS SDK IS DEPRECATED &mdash; PLEASE USE [`@oystehr/sdk`](https://www.npmjs.com/package/@oystehr/sdk).

### For more information about migrating to the new SDK, check our [Migration Guide](https://docs.oystehr.com/core-documentation/typescript-sdk/migration-guide/).

<br/>
<br/>
<br/>

# ZapEHR SDK

The ZapEHR SDK is a TypeScript library for interacting with ZapEHR's [FHIR and Project APIs](https://api-reference.zapehr.com).

While you can always make raw HTTP requests to ZapEHR's APIs from any language, this SDK provides several advantages for developers:

- TypeScript types &mdash; The SDK provides complete typing for requests and responses across all of ZapEHR's APIs. This gives you helpful autocomplete and build-time type checking.
- Convenience functions &mdash; The SDK provides convenience functions for doing common tasks like uploading and downloading files with Z3.

## Installation

```bash
npm install @zapehr/sdk
```

## Usage

1. Import the SDK.
2. Initialize the SDK with a ZapEHR access token. ([Learn how to get an access token](https://docs.zapehr.com/core-documentation/authenticating-api-requests)).
3. Invoke any of ZapEHR's APIs with a function call.

```typescript filename="Example of using the SDK"
import zapehr from '@zapehr/sdk'

zapehr.init({
  ZAPEHR_ACCESS_TOKEN: 'your_access_token',
});

// Create a Patient FHIR resource
const patient = await zapehr.fhir.create({
  resourceType: 'Patient',
});

// Upload a zambda
try {
  const zambda = await zapehr.project.zambda.create({ name: 'new zambda', triggerMethod: 'http_open' });
  const fileHandle = await fs.open('./path/to/my/zambda.zip')
  const file = new Blob([await fileHandle.readFile()]);
  await zapehr.project.zambda.uploadFile({ id: createZambda.data.id, file, })
} catch (err) {
  // Handle error thrown by ZapEHR or JS in some way
}
```

## Convenience Functions

### Z3

Under the hood, uploading and downloading files with [Z3](/services/z3) is a two-step process:

1. Create a presigned URL to upload or download the file ([API Reference](https://api-reference.zapehr.com/reference/post_z3-bucketname-objectpath)).
2. Upload or download the file using the presigned URL.

The SDK provides convenience functions which combine these steps into a single function call to make it a one-liner:

```typescript copy filename="Upload a file to Z3 with the SDK"
    await zapehr.project.z3.uploadFile(
      { bucketName: 'your-bucket-name', 'objectPath+': 'path/to/your-filename', file: someFileBlob }
    );
```

In the example, `someFileBlob` is a [Blob](https://nodejs.org/api/buffer.html#class-blob).

```typescript copy filename="Download a file from Z3 with the SDK"
    const downloadedBuffer = await zapehr.project.z3.downloadFile(
      { bucketName: 'your-bucket-name', 'objectPath+': 'path/to/your-filename' }
    );
```

### Zambda

Uploading code for your Zambda Functions is very similar to uploading a file with Z3. After creating your `.zip` archive, use the `uploadFile()` function to deploy your code.

```typescript copy filename="Deploy a code zip to a Zambda Function"
  const zambdaFile = fs.readFileSync('build/your-zambda-code.zip');
  await zapehr.project.zambda.uploadFile({
    id: yourZambdaId,
    file: new Blob([zambdaFile]),
  });
```
