'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

let globalConfig;
function getConfig() {
    if (!globalConfig) {
        throw new Error('Config not set, please initialize the SDK');
    }
    return globalConfig;
}
function setConfig(config) {
    globalConfig = Object.assign({}, config);
}

function formatAddress(address, options) {
    const builder = [];
    if (address.line) {
        builder.push(...address.line);
    }
    if (address.city || address.state || address.postalCode) {
        const cityStateZip = [];
        if (address.city) {
            cityStateZip.push(address.city);
        }
        if (address.state) {
            cityStateZip.push(address.state);
        }
        if (address.postalCode) {
            cityStateZip.push(address.postalCode);
        }
        builder.push(cityStateZip.join(', '));
    }
    if (address.use && ((options === null || options === void 0 ? void 0 : options.all) || (options === null || options === void 0 ? void 0 : options.use))) {
        builder.push('[' + address.use + ']');
    }
    return builder.join((options === null || options === void 0 ? void 0 : options.lineSeparator) || ', ').trim();
}
function formatHumanName(name, options) {
    const builder = [];
    if (name.prefix && (options === null || options === void 0 ? void 0 : options.prefix) !== false) {
        builder.push(...name.prefix);
    }
    if (name.given) {
        builder.push(...name.given);
    }
    if (name.family) {
        builder.push(name.family);
    }
    if (name.suffix && (options === null || options === void 0 ? void 0 : options.suffix) !== false) {
        builder.push(...name.suffix);
    }
    if (name.use && ((options === null || options === void 0 ? void 0 : options.all) || (options === null || options === void 0 ? void 0 : options.use))) {
        builder.push('[' + name.use + ']');
    }
    return builder.join(' ').trim();
}

var fhirUtils = /*#__PURE__*/Object.freeze({
    __proto__: null,
    formatAddress: formatAddress,
    formatHumanName: formatHumanName
});

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

function __awaiter(thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
}

typeof SuppressedError === "function" ? SuppressedError : function (error, suppressed, message) {
    var e = new Error(message);
    return e.name = "SuppressedError", e.error = error, e.suppressed = suppressed, e;
};

class ZapEHRSdkError extends Error {
    constructor({ message, code }) {
        super(message);
        Object.setPrototypeOf(this, ZapEHRSdkError.prototype);
        this.code = code;
        this.name = 'ZapEHRSdkError';
    }
    toString() {
        return `${this.name}: ${this.message} (code: ${this.code})`;
    }
}
class ZapEHRFHIRError extends ZapEHRSdkError {
    constructor({ error, code }) {
        super({ message: 'See cause for details', code });
        Object.setPrototypeOf(this, ZapEHRFHIRError.prototype);
        this.cause = error;
        this.name = 'ZapEHRFHIRError';
    }
}

/**
 * This file was auto-generated by openapi-typescript.
 * Do not make direct changes to the file.
 */
const servers$1 = ['https://project-api.zapehr.com/v1'];

function projectClient(path) {
    const baseUrl = () => { var _a; return (_a = getConfig().ZAPEHR_PROJECT_API_URL) !== null && _a !== void 0 ? _a : servers$1[0]; };
    return new Proxy(
    // @ts-expect-error proxy type shenanigans
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    { get() { }, post() { }, put() { }, delete() { }, options() { }, head() { }, patch() { } }, {
        get(_, method) {
            try {
                return fetcher(baseUrl, path, method);
            }
            catch (err) {
                const error = err;
                throw new ZapEHRSdkError(error);
            }
        },
    });
}
function fetcher(baseUrlThunk, path, methodParam) {
    return (params, request) => __awaiter(this, void 0, void 0, function* () {
        var _a, _b, _c, _d, _e, _f, _g, _h;
        // this function supports multiple signatures. fetcher(baseUrl, path, method)(params, request) or fetcher(baseUrl, path, method)(request)
        // or fetcher(baseUrl, path, method)(params) or fetcher(baseUrl, path, method)(). the types for this are handled by Client<Path, Methods>
        // and this is the backend implementation behind it. the heuristic we're using is that if the first param is an object with an accessToken
        // and there is no second param, assume the first one is the request object instead
        const providedParams = !!params && !request && !Array.isArray(params) && params['accessToken'] ? {} : params !== null && params !== void 0 ? params : {};
        const requestCtx = !!params && !request && !Array.isArray(params) && params['accessToken']
            ? params
            : request;
        const method = methodParam.toLowerCase();
        const accessToken = (_a = requestCtx === null || requestCtx === void 0 ? void 0 : requestCtx.accessToken) !== null && _a !== void 0 ? _a : getConfig().ZAPEHR_ACCESS_TOKEN;
        const projectId = (_b = requestCtx === null || requestCtx === void 0 ? void 0 : requestCtx.projectId) !== null && _b !== void 0 ? _b : getConfig().ZAPEHR_PROJECT_ID;
        let finalPath = path;
        let finalParams = providedParams;
        if (!Array.isArray(providedParams)) {
            const [subbedPath, addlParams] = subParamsInPath(path, providedParams);
            finalPath = subbedPath;
            finalParams = addlParams;
        }
        finalPath = finalPath.replace(/^\//, ''); // remove leading slash
        const baseUrlEvaluated = baseUrlThunk();
        const fullBaseUrl = baseUrlEvaluated.endsWith('/') ? baseUrlEvaluated : baseUrlEvaluated + '/';
        const url = new URL(finalPath, fullBaseUrl);
        let body;
        if (Array.isArray(finalParams)) {
            body = JSON.stringify(finalParams);
        }
        else if (Object.keys(finalParams).length) {
            if (method === 'get') {
                addParamsToSearch(finalParams, url.searchParams);
            }
            else if ((requestCtx === null || requestCtx === void 0 ? void 0 : requestCtx.contentType) === 'application/x-www-form-urlencoded') {
                const search = new URLSearchParams();
                addParamsToSearch(finalParams, search);
                body = search.toString();
            }
            else {
                body = JSON.stringify(finalParams);
            }
        }
        else {
            // override for rpc call
            if (method === 'post') {
                body = '{}';
            }
        }
        // @ts-expect-error this isn't correctly determining requestCtx.projectId is defined in the ternary expression
        const headers = Object.assign(projectId
            ? {
                'x-zapehr-project-id': projectId,
            }
            : {}, {
            Authorization: `Bearer ${accessToken}`,
            'content-type': (_c = requestCtx === null || requestCtx === void 0 ? void 0 : requestCtx.contentType) !== null && _c !== void 0 ? _c : 'application/json',
        }, (requestCtx === null || requestCtx === void 0 ? void 0 : requestCtx.ifMatch) ? { 'If-Match': requestCtx.ifMatch } : {});
        const response = yield fetch(new Request(url, {
            method: method.toUpperCase(),
            body,
            headers,
        }));
        const responseBody = response.body ? yield response.text() : null;
        const responseJson = responseBody &&
            (((_d = response.headers.get('content-type')) === null || _d === void 0 ? void 0 : _d.includes('application/json')) ||
                ((_e = response.headers.get('content-type')) === null || _e === void 0 ? void 0 : _e.includes('application/fhir+json')))
            ? JSON.parse(responseBody)
            : null;
        const isError = !response.ok || response.status >= 400;
        if (isError) {
            throw {
                message: (_g = (_f = responseJson === null || responseJson === void 0 ? void 0 : responseJson.message) !== null && _f !== void 0 ? _f : responseJson) !== null && _g !== void 0 ? _g : responseBody,
                code: (_h = responseJson === null || responseJson === void 0 ? void 0 : responseJson.code) !== null && _h !== void 0 ? _h : response.status,
            };
        }
        return responseJson;
    });
}
/**
 * Substitutes params in a path and returns the path with params substituted and any unused params.
 *
 * Uses the property names in the params object to determine the param to substitute in the path.
 *
 * @param path JSON API resource URI
 * @param params all params provided to the client method
 * @returns resource URI with params substituted and any unused params
 */
function subParamsInPath(path, params) {
    const unusedParams = Object.assign({}, params);
    // capture everything of the form `{paramName}` and replace with the value of `params[paramName]`
    const subbedPath = path.replace(/\{([^}]+)\}/g, (_, paramName) => {
        delete unusedParams[paramName];
        // override for path params that are paths, indicated by a `+` at the end
        if (paramName.match(/^.*\+$/)) {
            return params[paramName] + '';
        }
        // error if param value is empty
        if (!params[paramName] || params[paramName] === '') {
            throw new ZapEHRSdkError({ message: `Required path parameter is an empty string: ${paramName}`, code: 400 });
        }
        // encode search params
        if (params[paramName]) {
            return encodeURIComponent(params[paramName] + ''); // coerce to string
        }
        return '';
    });
    const unusedKeys = Object.keys(unusedParams);
    const addlParams = unusedKeys.length
        ? unusedKeys.reduce((acc, key) => (Object.assign(Object.assign({}, acc), { [key]: unusedParams[key] })), {})
        : {};
    return [subbedPath, addlParams];
}
/**
 * Adds params to a URLSearchParams object in such a way as to preserve array values.
 * @param params params
 * @param search URLSearchParams object
 */
function addParamsToSearch(params, search) {
    for (const [key, value] of Object.entries(params)) {
        if (Array.isArray(value)) {
            value.forEach((v) => search.append(key, v));
            continue;
        }
        search.append(key, value);
    }
}

const servers = ['https://fhir-api.zapehr.com'];

function getServer() {
    var _a;
    return (_a = getConfig().ZAPEHR_FHIR_API_URL) !== null && _a !== void 0 ? _a : servers[0];
}
function fhirFetcher(path, method) {
    return (params, request) => __awaiter(this, void 0, void 0, function* () {
        try {
            // must await here to catch
            return yield fetcher(getServer, path, method)(params, request);
        }
        catch (err) {
            // FHIR API error messages are JSON strings
            const fullError = err;
            if (typeof fullError.message === 'string') {
                throw new ZapEHRSdkError({
                    message: fullError.message,
                    code: fullError.code,
                });
            }
            throw new ZapEHRFHIRError({
                error: fullError.message,
                code: fullError.code,
            });
        }
    });
}
/**
 * @deprecated Use `search` instead
 *
 * Performs a FHIR search and returns the results as an array of FHIR resources
 *
 * @param options FHIR resource type and FHIR search parameters
 * @param request optional ZapEHRClientRequest object
 * @returns Array of FHIR resources
 */
function list({ resourceType, params }, request) {
    return __awaiter(this, void 0, void 0, function* () {
        const listResp = yield listAsBundle({ resourceType, params }, request);
        const resources = listResp.entry ? listResp.entry.map((entry) => entry.resource) : [];
        return resources;
    });
}
/**
 * @deprecated Use `search` instead
 *
 * Performs a FHIR search and returns the results as a Bundle resource
 *
 * @param options FHIR resource type and FHIR search parameters
 * @param request optional ZapEHRClientRequest object
 * @returns FHIR Bundle resource
 */
function listAsBundle({ resourceType, params }, request) {
    return __awaiter(this, void 0, void 0, function* () {
        return search({ resourceType, params }, request);
    });
}
/**
 * Performs a FHIR search and returns the results as a Bundle resource
 *
 * @param options FHIR resource type and FHIR search parameters
 * @param request optional ZapEHRClientRequest object
 * @returns FHIR Bundle resource
 */
function search({ resourceType, params }, request) {
    return __awaiter(this, void 0, void 0, function* () {
        let paramMap = {};
        if (params) {
            paramMap = Object.entries(params).reduce((acc, [_, param]) => {
                if (!acc[param.name]) {
                    acc[param.name] = [];
                }
                acc[param.name].push(param.value);
                return acc;
            }, {});
        }
        return fhirFetcher(`/${resourceType}/_search`, 'POST')(paramMap, Object.assign(Object.assign({}, request), { contentType: 'application/x-www-form-urlencoded' }));
    });
}
function create(params, request) {
    return __awaiter(this, void 0, void 0, function* () {
        const { resourceType } = params;
        return fhirFetcher(`/${resourceType}`, 'POST')(params, request);
    });
}
function get({ resourceType, id }, request) {
    return __awaiter(this, void 0, void 0, function* () {
        return fhirFetcher(`/${resourceType}/${id}`, 'GET')({}, request);
    });
}
function update(params, request) {
    return __awaiter(this, void 0, void 0, function* () {
        const { id, resourceType } = params;
        return fhirFetcher(`/${resourceType}/${id}`, 'PUT')(params, Object.assign(Object.assign({}, request), { ifMatch: (request === null || request === void 0 ? void 0 : request.optimisticLockingVersionId) ? `W/"${request.optimisticLockingVersionId}"` : undefined }));
    });
}
function patch({ resourceType, id, operations }, request) {
    return __awaiter(this, void 0, void 0, function* () {
        return fhirFetcher(`/${resourceType}/${id}`, 'PATCH')(operations, Object.assign(Object.assign({}, request), { contentType: 'application/json-patch+json', ifMatch: (request === null || request === void 0 ? void 0 : request.optimisticLockingVersionId) ? `W/"${request.optimisticLockingVersionId}"` : undefined }));
    });
}
function del({ resourceType, id }, request) {
    return __awaiter(this, void 0, void 0, function* () {
        return fhirFetcher(`/${resourceType}/${id}`, 'DELETE')({}, request);
    });
}
function history({ resourceType, id, versionId }, request) {
    return __awaiter(this, void 0, void 0, function* () {
        return fhirFetcher(`/${resourceType}/${id}/_history${versionId ? `/${versionId}` : ''}`, 'GET')({}, request);
    });
}
function batchInputRequestToBundleEntryItem(request) {
    const { method, url } = request;
    const baseRequest = {
        request: {
            method,
            url,
        },
    };
    if (url.split('?').length > 1) {
        const [resource, query] = url.split('?');
        const params = query
            .split('&')
            .map((param) => {
            const [name, value] = param.split('=');
            return { name, value };
        })
            .reduce((acc, { name, value }) => {
            acc[name] = value;
            return acc;
        }, {});
        const search = new URLSearchParams();
        addParamsToSearch(params, search);
        baseRequest.request.url = `${resource}?${search.toString()}`;
    }
    if (['GET', 'DELETE', 'HEAD'].includes(method)) {
        return baseRequest;
    }
    if (method === 'PUT' || method === 'PATCH') {
        const { resource } = request;
        return Object.assign(Object.assign({}, baseRequest), { resource });
    }
    if (method === 'POST') {
        const { resource, fullUrl } = request;
        return Object.assign(Object.assign({}, baseRequest), { resource,
            fullUrl });
    }
    throw new Error('Unrecognized method');
}
function bundleRequest(type) {
    return function (input, request) {
        return __awaiter(this, void 0, void 0, function* () {
            return fhirFetcher('/', 'POST')({
                resourceType: 'Bundle',
                type,
                entry: input.requests.map(batchInputRequestToBundleEntryItem),
            }, request);
        });
    };
}
const batch = bundleRequest('batch');
const transaction = bundleRequest('transaction');

var index$2 = /*#__PURE__*/Object.freeze({
    __proto__: null,
    list: list,
    listAsBundle: listAsBundle,
    search: search,
    create: create,
    get: get,
    update: update,
    patch: patch,
    'delete': del,
    history: history,
    batch: batch,
    transaction: transaction
});

const application = {
    list: projectClient('/application').get,
    create: projectClient('/application').post,
    get: projectClient('/application/{id}').get,
    delete: projectClient('/application/{id}').delete,
    update: projectClient('/application/{id}').patch,
    revokeAccessToken: projectClient('/application/{id}/revoke-access-token').post,
    revokeRefreshToken: projectClient('/application/{id}/revoke-refresh-token').post,
    rotateSecret: projectClient('/application/{id}/rotate-secret').post,
};

const developer = {
    list: projectClient('/developer').get,
    get: projectClient('/developer/{id}').get,
    delete: projectClient('/developer/{id}').delete,
    update: projectClient('/developer/{id}').patch,
    invite: projectClient('/developer/invite').post,
    listV2: projectClient('/developer/v2/list').get,
};

const erx = {
    allergySearch: projectClient('/erx/allergy/search').get,
    medicationSearch: projectClient('/erx/medication/search').get,
    syncPatient: projectClient('/erx/sync-patient/{patientId}').post,
};

const role = {
    list: projectClient('/iam/role').get,
    create: projectClient('/iam/role').post,
    get: projectClient('/iam/role/{roleId}').get,
    delete: projectClient('/iam/role/{roleId}').delete,
    update: projectClient('/iam/role/{roleId}').patch,
};

const m2m = {
    list: projectClient('/m2m').get,
    create: projectClient('/m2m').post,
    get: projectClient('/m2m/{id}').get,
    delete: projectClient('/m2m/{id}').delete,
    update: projectClient('/m2m/{id}').patch,
    rotateSecret: projectClient('/m2m/{id}/rotate-secret').post,
    listV2: projectClient('/m2m/v2/list').get,
};

const messaging = {
    getMessagingConfig: projectClient('/messaging/config').get,
};

const ENCOUNTER_VS_EXTENSION_URL = 'https://extensions.fhir.zapehr.com/encounter-virtual-service-pre-release';
const ENCOUNTER_VS_EXTENSION_RELATIVE_URL = 'addressString';
const ENCOUNTER_VS_CODING_SYSTEM = 'https://fhir.zapehr.com/virtual-service-type';
function isR5Encounter(encounter) {
    return Object.hasOwn(encounter, 'virtualService');
}
/**
 * Helper function to get a conversationId from an encounter created as a ZapEHR Conversation
 * @param encounter well-formed FHIR R4B or R5 Encounter
 * @returns conversationId
 */
function getConversationIdFromEncounter(encounter) {
    var _a, _b, _c;
    if (isR5Encounter(encounter)) {
        const virtualService = (_a = encounter.virtualService) === null || _a === void 0 ? void 0 : _a.find((vs) => { var _a; return ((_a = vs.channelType) === null || _a === void 0 ? void 0 : _a.system) === ENCOUNTER_VS_CODING_SYSTEM; });
        return virtualService === null || virtualService === void 0 ? void 0 : virtualService.addressString;
    }
    if (!encounter.extension)
        return;
    const virtualServiceExtension = encounter.extension.find((extension) => extension.url === ENCOUNTER_VS_EXTENSION_URL);
    if (!(virtualServiceExtension === null || virtualServiceExtension === void 0 ? void 0 : virtualServiceExtension.extension))
        return;
    const conversationId = (_c = (_b = virtualServiceExtension.extension) === null || _b === void 0 ? void 0 : _b.find((extension) => extension.url === ENCOUNTER_VS_EXTENSION_RELATIVE_URL)) === null || _c === void 0 ? void 0 : _c.valueString;
    return conversationId;
}

var ext$2 = /*#__PURE__*/Object.freeze({
    __proto__: null,
    ENCOUNTER_VS_EXTENSION_URL: ENCOUNTER_VS_EXTENSION_URL,
    ENCOUNTER_VS_EXTENSION_RELATIVE_URL: ENCOUNTER_VS_EXTENSION_RELATIVE_URL,
    getConversationIdFromEncounter: getConversationIdFromEncounter
});

const conversation = Object.assign({ create: projectClient('/messaging/conversation').post, message: projectClient('/messaging/conversation/{conversationId}/message').post, participant: projectClient('/messaging/conversation/{conversationId}/participant').post, removeParticipant: projectClient('/messaging/conversation/{conversationId}/participant').delete, getToken: projectClient('/messaging/conversation/token').get }, ext$2);

const transactionalSMS = {
    send: projectClient('/messaging/transactional-sms/send').post,
};

const charge = {
    issue: projectClient('/payment/charge/issue').post,
    status: projectClient('/payment/charge/status').post,
};

const paymentMethod = {
    delete: projectClient('/payment/payment-method').delete,
    list: projectClient('/payment/payment-method/list').post,
    setDefault: projectClient('/payment/payment-method/set-default').post,
    setup: projectClient('/payment/payment-method/setup').post,
};

const project = {
    get: projectClient('/project').get,
    update: projectClient('/project').patch,
};

const rcm = {
    eligibilityCheck: projectClient('/rcm/eligibility-check').post,
    submitProfessionalClaim: projectClient('/rcm/professional-claim/submit').post,
    validateProfessionalClaim: projectClient('/rcm/professional-claim/validate').post,
};

const secret = {
    list: projectClient('/secret').get,
    create: projectClient('/secret').post,
    get: projectClient('/secret/{name}').get,
    delete: projectClient('/secret/{name}').delete,
};

const telemed = {
    meeting: projectClient('/telemed/v2/meeting').post,
    join: projectClient('/telemed/v2/meeting/{encounterId}/join').get,
};

const user = {
    list: projectClient('/user').get,
    get: projectClient('/user/{id}').get,
    delete: projectClient('/user/{id}').delete,
    update: projectClient('/user/{id}').patch,
    invite: projectClient('/user/invite').post,
    me: projectClient('/user/me').get,
    listV2: projectClient('/user/v2/list').get,
};

const version = {
    get: projectClient('/version').get,
};

function uploadFile$1({ bucketName, 'objectPath+': key, file, }) {
    return __awaiter(this, void 0, void 0, function* () {
        const uploadUrl = yield projectClient('/z3/{bucketName}/{objectPath+}').post({
            action: 'upload',
            bucketName,
            'objectPath+': key,
        });
        yield fetch(uploadUrl.signedUrl, {
            method: 'PUT',
            body: file,
        });
    });
}
function downloadFile({ bucketName, 'objectPath+': key, }) {
    return __awaiter(this, void 0, void 0, function* () {
        const uploadUrl = yield projectClient('/z3/{bucketName}/{objectPath+}').post({
            action: 'download',
            bucketName,
            'objectPath+': key,
        });
        const resp = yield fetch(uploadUrl.signedUrl, {
            method: 'GET',
        });
        if (!resp.ok) {
            throw new Error('Failed to download file');
        }
        return resp.arrayBuffer();
    });
}

var ext$1 = /*#__PURE__*/Object.freeze({
    __proto__: null,
    uploadFile: uploadFile$1,
    downloadFile: downloadFile
});

const z3 = Object.assign({ listBuckets: projectClient('/z3').get, createBucket: projectClient('/z3/{bucketName}').put, deleteBucket: projectClient('/z3/{bucketName}').delete, listObjects: projectClient('/z3/{bucketName}/{objectPath+}').get, getPresignedUrl: projectClient('/z3/{bucketName}/{objectPath+}').post, deleteObject: projectClient('/z3/{bucketName}/{objectPath+}').delete }, ext$1);

function uploadFile({ id, file, filename, }) {
    return __awaiter(this, void 0, void 0, function* () {
        const uploadUrl = yield projectClient('/zambda/{id}/s3-upload').post({ id, filename });
        yield fetch(uploadUrl.signedUrl, {
            method: 'PUT',
            body: file,
        });
    });
}

var ext = /*#__PURE__*/Object.freeze({
    __proto__: null,
    uploadFile: uploadFile
});

const zambda = Object.assign({ list: projectClient('/zambda').get, create: projectClient('/zambda').post, get: projectClient('/zambda/{id}').get, delete: projectClient('/zambda/{id}').delete, update: projectClient('/zambda/{id}').patch, execute: projectClient('/zambda/{id}/execute').post, executePublic: projectClient('/zambda/{id}/execute-public').post, s3Upload: projectClient('/zambda/{id}/s3-upload').post, logStream: {
        list: projectClient('/zambda/{id}/logStream').post,
        get: projectClient('/zambda/{id}/logStream/{logStreamName}').post,
        search: projectClient('/zambda/{id}/logStream/search').post,
    } }, ext);

var index$1 = /*#__PURE__*/Object.freeze({
    __proto__: null,
    application: application,
    developer: developer,
    erx: erx,
    role: role,
    m2m: m2m,
    messaging: messaging,
    conversation: conversation,
    transactionalSMS: transactionalSMS,
    charge: charge,
    paymentMethod: paymentMethod,
    project: project,
    rcm: rcm,
    secret: secret,
    telemed: telemed,
    user: user,
    version: version,
    z3: z3,
    zambda: zambda
});

var resources = /*#__PURE__*/Object.freeze({
    __proto__: null,
    fhir: index$2,
    project: index$1
});

var index = Object.assign(Object.assign(Object.assign({}, resources), fhirUtils), { init: setConfig });

exports.ZapEHRFHIRError = ZapEHRFHIRError;
exports.ZapEHRSdkError = ZapEHRSdkError;
exports["default"] = index;
//# sourceMappingURL=index.js.map
