import { __awaiter } from '../node_modules/tslib/tslib.es6.mjs.js';
import { getConfig } from '../config.js';
import { ZapEHRSdkError } from '../errors/index.js';
import { servers } from './openapi/project-api.js';

function projectClient(path) {
    const baseUrl = () => { var _a; return (_a = getConfig().ZAPEHR_PROJECT_API_URL) !== null && _a !== void 0 ? _a : servers[0]; };
    return new Proxy(
    // @ts-expect-error proxy type shenanigans
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    { get() { }, post() { }, put() { }, delete() { }, options() { }, head() { }, patch() { } }, {
        get(_, method) {
            try {
                return fetcher(baseUrl, path, method);
            }
            catch (err) {
                const error = err;
                throw new ZapEHRSdkError(error);
            }
        },
    });
}
function fetcher(baseUrlThunk, path, methodParam) {
    return (params, request) => __awaiter(this, void 0, void 0, function* () {
        var _a, _b, _c, _d, _e, _f, _g, _h;
        // this function supports multiple signatures. fetcher(baseUrl, path, method)(params, request) or fetcher(baseUrl, path, method)(request)
        // or fetcher(baseUrl, path, method)(params) or fetcher(baseUrl, path, method)(). the types for this are handled by Client<Path, Methods>
        // and this is the backend implementation behind it. the heuristic we're using is that if the first param is an object with an accessToken
        // and there is no second param, assume the first one is the request object instead
        const providedParams = !!params && !request && !Array.isArray(params) && params['accessToken'] ? {} : params !== null && params !== void 0 ? params : {};
        const requestCtx = !!params && !request && !Array.isArray(params) && params['accessToken']
            ? params
            : request;
        const method = methodParam.toLowerCase();
        const accessToken = (_a = requestCtx === null || requestCtx === void 0 ? void 0 : requestCtx.accessToken) !== null && _a !== void 0 ? _a : getConfig().ZAPEHR_ACCESS_TOKEN;
        const projectId = (_b = requestCtx === null || requestCtx === void 0 ? void 0 : requestCtx.projectId) !== null && _b !== void 0 ? _b : getConfig().ZAPEHR_PROJECT_ID;
        let finalPath = path;
        let finalParams = providedParams;
        if (!Array.isArray(providedParams)) {
            const [subbedPath, addlParams] = subParamsInPath(path, providedParams);
            finalPath = subbedPath;
            finalParams = addlParams;
        }
        finalPath = finalPath.replace(/^\//, ''); // remove leading slash
        const baseUrlEvaluated = baseUrlThunk();
        const fullBaseUrl = baseUrlEvaluated.endsWith('/') ? baseUrlEvaluated : baseUrlEvaluated + '/';
        const url = new URL(finalPath, fullBaseUrl);
        let body;
        if (Array.isArray(finalParams)) {
            body = JSON.stringify(finalParams);
        }
        else if (Object.keys(finalParams).length) {
            if (method === 'get') {
                addParamsToSearch(finalParams, url.searchParams);
            }
            else if ((requestCtx === null || requestCtx === void 0 ? void 0 : requestCtx.contentType) === 'application/x-www-form-urlencoded') {
                const search = new URLSearchParams();
                addParamsToSearch(finalParams, search);
                body = search.toString();
            }
            else {
                body = JSON.stringify(finalParams);
            }
        }
        else {
            // override for rpc call
            if (method === 'post') {
                body = '{}';
            }
        }
        // @ts-expect-error this isn't correctly determining requestCtx.projectId is defined in the ternary expression
        const headers = Object.assign(projectId
            ? {
                'x-zapehr-project-id': projectId,
            }
            : {}, {
            Authorization: `Bearer ${accessToken}`,
            'content-type': (_c = requestCtx === null || requestCtx === void 0 ? void 0 : requestCtx.contentType) !== null && _c !== void 0 ? _c : 'application/json',
        }, (requestCtx === null || requestCtx === void 0 ? void 0 : requestCtx.ifMatch) ? { 'If-Match': requestCtx.ifMatch } : {});
        const response = yield fetch(new Request(url, {
            method: method.toUpperCase(),
            body,
            headers,
        }));
        const responseBody = response.body ? yield response.text() : null;
        const responseJson = responseBody &&
            (((_d = response.headers.get('content-type')) === null || _d === void 0 ? void 0 : _d.includes('application/json')) ||
                ((_e = response.headers.get('content-type')) === null || _e === void 0 ? void 0 : _e.includes('application/fhir+json')))
            ? JSON.parse(responseBody)
            : null;
        const isError = !response.ok || response.status >= 400;
        if (isError) {
            throw {
                message: (_g = (_f = responseJson === null || responseJson === void 0 ? void 0 : responseJson.message) !== null && _f !== void 0 ? _f : responseJson) !== null && _g !== void 0 ? _g : responseBody,
                code: (_h = responseJson === null || responseJson === void 0 ? void 0 : responseJson.code) !== null && _h !== void 0 ? _h : response.status,
            };
        }
        return responseJson;
    });
}
/**
 * Substitutes params in a path and returns the path with params substituted and any unused params.
 *
 * Uses the property names in the params object to determine the param to substitute in the path.
 *
 * @param path JSON API resource URI
 * @param params all params provided to the client method
 * @returns resource URI with params substituted and any unused params
 */
function subParamsInPath(path, params) {
    const unusedParams = Object.assign({}, params);
    // capture everything of the form `{paramName}` and replace with the value of `params[paramName]`
    const subbedPath = path.replace(/\{([^}]+)\}/g, (_, paramName) => {
        delete unusedParams[paramName];
        // override for path params that are paths, indicated by a `+` at the end
        if (paramName.match(/^.*\+$/)) {
            return params[paramName] + '';
        }
        // error if param value is empty
        if (!params[paramName] || params[paramName] === '') {
            throw new ZapEHRSdkError({ message: `Required path parameter is an empty string: ${paramName}`, code: 400 });
        }
        // encode search params
        if (params[paramName]) {
            return encodeURIComponent(params[paramName] + ''); // coerce to string
        }
        return '';
    });
    const unusedKeys = Object.keys(unusedParams);
    const addlParams = unusedKeys.length
        ? unusedKeys.reduce((acc, key) => (Object.assign(Object.assign({}, acc), { [key]: unusedParams[key] })), {})
        : {};
    return [subbedPath, addlParams];
}
/**
 * Adds params to a URLSearchParams object in such a way as to preserve array values.
 * @param params params
 * @param search URLSearchParams object
 */
function addParamsToSearch(params, search) {
    for (const [key, value] of Object.entries(params)) {
        if (Array.isArray(value)) {
            value.forEach((v) => search.append(key, v));
            continue;
        }
        search.append(key, value);
    }
}

export { addParamsToSearch, fetcher, projectClient };
//# sourceMappingURL=client.js.map
