const ENCOUNTER_VS_EXTENSION_URL = 'https://extensions.fhir.zapehr.com/encounter-virtual-service-pre-release';
const ENCOUNTER_VS_EXTENSION_RELATIVE_URL = 'addressString';
const ENCOUNTER_VS_CODING_SYSTEM = 'https://fhir.zapehr.com/virtual-service-type';
function isR5Encounter(encounter) {
    return Object.hasOwn(encounter, 'virtualService');
}
/**
 * Helper function to get a conversationId from an encounter created as a ZapEHR Conversation
 * @param encounter well-formed FHIR R4B or R5 Encounter
 * @returns conversationId
 */
function getConversationIdFromEncounter(encounter) {
    var _a, _b, _c;
    if (isR5Encounter(encounter)) {
        const virtualService = (_a = encounter.virtualService) === null || _a === void 0 ? void 0 : _a.find((vs) => { var _a; return ((_a = vs.channelType) === null || _a === void 0 ? void 0 : _a.system) === ENCOUNTER_VS_CODING_SYSTEM; });
        return virtualService === null || virtualService === void 0 ? void 0 : virtualService.addressString;
    }
    if (!encounter.extension)
        return;
    const virtualServiceExtension = encounter.extension.find((extension) => extension.url === ENCOUNTER_VS_EXTENSION_URL);
    if (!(virtualServiceExtension === null || virtualServiceExtension === void 0 ? void 0 : virtualServiceExtension.extension))
        return;
    const conversationId = (_c = (_b = virtualServiceExtension.extension) === null || _b === void 0 ? void 0 : _b.find((extension) => extension.url === ENCOUNTER_VS_EXTENSION_RELATIVE_URL)) === null || _c === void 0 ? void 0 : _c.valueString;
    return conversationId;
}

export { ENCOUNTER_VS_EXTENSION_RELATIVE_URL, ENCOUNTER_VS_EXTENSION_URL, getConversationIdFromEncounter };
//# sourceMappingURL=conversation-ext.js.map
